==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/StatusFluent.java <==
package me.snowdrop.istio.api;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface StatusFluent<A extends StatusFluent<A>> extends Fluent<A>{


    public Integer getCode();
    public A withCode(Integer code);
    public Boolean hasCode();
    public A withNewCode(String arg1);
    public A withNewCode(int arg1);
    public A addToDetails(int index,Any item);
    public A setToDetails(int index,Any item);
    public A addToDetails(Any... items);
    public A addAllToDetails(Collection<Any> items);
    public A removeFromDetails(Any... items);
    public A removeAllFromDetails(Collection<Any> items);
    
/**
 * This method has been deprecated, please use method buildDetails instead.
 * @return The buildable object.
 */
@Deprecated public List<Any> getDetails();
    public List<Any> buildDetails();
    public Any buildDetail(int index);
    public Any buildFirstDetail();
    public Any buildLastDetail();
    public Any buildMatchingDetail(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    public A withDetails(List<Any> details);
    public A withDetails(Any... details);
    public Boolean hasDetails();
    public A addNewDetail(String typeUrl,String value);
    public StatusFluent.DetailsNested<A> addNewDetail();
    public StatusFluent.DetailsNested<A> addNewDetailLike(Any item);
    public StatusFluent.DetailsNested<A> setNewDetailLike(int index,Any item);
    public StatusFluent.DetailsNested<A> editDetail(int index);
    public StatusFluent.DetailsNested<A> editFirstDetail();
    public StatusFluent.DetailsNested<A> editLastDetail();
    public StatusFluent.DetailsNested<A> editMatchingDetail(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();

    public interface DetailsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AnyFluent<StatusFluent.DetailsNested<N>>{

        
    public N and();    public N endDetail();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/StatusFluent.java <==
package me.snowdrop.istio.api;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface StatusFluent<A extends StatusFluent<A>> extends Fluent<A>{


    public Integer getCode();
    public A withCode(Integer code);
    public Boolean hasCode();
    public A addToDetails(int index,Any item);
    public A setToDetails(int index,Any item);
    public A addToDetails(Any... items);
    public A addAllToDetails(Collection<Any> items);
    public A removeFromDetails(Any... items);
    public A removeAllFromDetails(Collection<Any> items);
    public A removeMatchingFromDetails(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDetails instead.
 * @return The buildable object.
 */
@Deprecated public List<Any> getDetails();
    public List<Any> buildDetails();
    public Any buildDetail(int index);
    public Any buildFirstDetail();
    public Any buildLastDetail();
    public Any buildMatchingDetail(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    public Boolean hasMatchingDetail(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    public A withDetails(List<Any> details);
    public A withDetails(Any... details);
    public Boolean hasDetails();
    public A addNewDetail(String typeUrl,String value);
    public StatusFluent.DetailsNested<A> addNewDetail();
    public StatusFluent.DetailsNested<A> addNewDetailLike(Any item);
    public StatusFluent.DetailsNested<A> setNewDetailLike(int index,Any item);
    public StatusFluent.DetailsNested<A> editDetail(int index);
    public StatusFluent.DetailsNested<A> editFirstDetail();
    public StatusFluent.DetailsNested<A> editLastDetail();
    public StatusFluent.DetailsNested<A> editMatchingDetail(io.fabric8.kubernetes.api.builder.Predicate<AnyBuilder> predicate);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);

    public interface DetailsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AnyFluent<StatusFluent.DetailsNested<N>>{

        
    public N and();    public N endDetail();
}


}
